﻿using Infrastructure;
using Infrastructure.Attribute;
using Infrastructure.Enums;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using ZR.Model.Dto;
using ZR.Model.Models;
using ZR.Service.Business.IBusinessService;
using ZR.Admin.WebApi.Extensions;
using ZR.Admin.WebApi.Filters;
using ZR.Common;

namespace ZR.Admin.WebApi.Controllers
{
    /// <summary>
    /// 接口管理/SAP关键件清单记录表Controller
    /// 
    /// @tableName sap_bom_record
    /// @author admin
    /// @date 2023-05-05
    /// </summary>
    [Verify]
    [Route("business/SapBomRecord")]
    public class SapBomRecordController : BaseController
    {
        /// <summary>
        /// 接口管理/SAP关键件清单记录表接口
        /// </summary>
        private readonly ISapBomRecordService _SapBomRecordService;

        public SapBomRecordController(ISapBomRecordService SapBomRecordService)
        {
            _SapBomRecordService = SapBomRecordService;
        }

        /// <summary>
        /// 查询接口管理/SAP关键件清单记录表列表
        /// </summary>
        /// <param name="parm"></param>
        /// <returns></returns>
        [HttpGet("list")]
        [ActionPermissionFilter(Permission = "business:sapbomrecord:list")]
        public IActionResult QuerySapBomRecord([FromQuery] SapBomRecordQueryDto parm)
        {
            var response = _SapBomRecordService.GetList(parm);
            return SUCCESS(response);
        }


        /// <summary>
        /// 查询接口管理/SAP关键件清单记录表详情
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        [HttpGet("{Id}")]
        [ActionPermissionFilter(Permission = "business:sapbomrecord:query")]
        public IActionResult GetSapBomRecord(int Id)
        {
            var response = _SapBomRecordService.GetFirst(x => x.Id == Id);

            return SUCCESS(response);
        }

        /// <summary>
        /// 添加接口管理/SAP关键件清单记录表
        /// </summary>
        /// <returns></returns>
        [HttpPost]
        [ActionPermissionFilter(Permission = "business:sapbomrecord:add")]
        [Log(Title = "接口管理/SAP关键件清单记录表", BusinessType = BusinessType.INSERT)]
        public IActionResult AddSapBomRecord([FromBody] SapBomRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求参数错误");
            }
            var modal = parm.Adapt<SapBomRecord>().ToCreate(HttpContext);

            var response = _SapBomRecordService.AddSapBomRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 更新接口管理/SAP关键件清单记录表
        /// </summary>
        /// <returns></returns>
        [HttpPut]
        [ActionPermissionFilter(Permission = "business:sapbomrecord:edit")]
        [Log(Title = "接口管理/SAP关键件清单记录表", BusinessType = BusinessType.UPDATE)]
        public IActionResult UpdateSapBomRecord([FromBody] SapBomRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求实体不能为空");
            }
            var modal = parm.Adapt<SapBomRecord>().ToUpdate(HttpContext);

            var response = _SapBomRecordService.UpdateSapBomRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 删除接口管理/SAP关键件清单记录表
        /// </summary>
        /// <returns></returns>
        [HttpDelete("{ids}")]
        [ActionPermissionFilter(Permission = "business:sapbomrecord:delete")]
        [Log(Title = "接口管理/SAP关键件清单记录表", BusinessType = BusinessType.DELETE)]
        public IActionResult DeleteSapBomRecord(string ids)
        {
            int[] idsArr = Tools.SpitIntArrary(ids);
            if (idsArr.Length <= 0) { return ToResponse(ApiResult.Error($"删除失败Id 不能为空")); }

            var response = _SapBomRecordService.Delete(idsArr);

            return ToResponse(response);
        }



    }
}