﻿using Infrastructure;
using Infrastructure.Attribute;
using Infrastructure.Enums;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using ZR.Model.Dto;
using ZR.Model.Models;
using ZR.Service.Business.IBusinessService;
using ZR.Admin.WebApi.Extensions;
using ZR.Admin.WebApi.Filters;
using ZR.Common;

namespace ZR.Admin.WebApi.Controllers
{
    /// <summary>
    /// 接口管理/SAP交验单记录表Controller
    /// 
    /// @tableName sap_deliver_record
    /// @author admin
    /// @date 2023-05-05
    /// </summary>
    [Verify]
    [Route("business/SapDeliverRecord")]
    public class SapDeliverRecordController : BaseController
    {
        /// <summary>
        /// 接口管理/SAP交验单记录表接口
        /// </summary>
        private readonly ISapDeliverRecordService _SapDeliverRecordService;

        public SapDeliverRecordController(ISapDeliverRecordService SapDeliverRecordService)
        {
            _SapDeliverRecordService = SapDeliverRecordService;
        }

        /// <summary>
        /// 查询接口管理/SAP交验单记录表列表
        /// </summary>
        /// <param name="parm"></param>
        /// <returns></returns>
        [HttpGet("list")]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:list")]
        public IActionResult QuerySapDeliverRecord([FromQuery] SapDeliverRecordQueryDto parm)
        {
            var response = _SapDeliverRecordService.GetList(parm);
            return SUCCESS(response);
        }


        /// <summary>
        /// 查询接口管理/SAP交验单记录表详情
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        [HttpGet("{Id}")]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:query")]
        public IActionResult GetSapDeliverRecord(int Id)
        {
            var response = _SapDeliverRecordService.GetFirst(x => x.Id == Id);

            return SUCCESS(response);
        }

        /// <summary>
        /// 添加接口管理/SAP交验单记录表
        /// </summary>
        /// <returns></returns>
        [HttpPost]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:add")]
        [Log(Title = "接口管理/SAP交验单记录表", BusinessType = BusinessType.INSERT)]
        public IActionResult AddSapDeliverRecord([FromBody] SapDeliverRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求参数错误");
            }
            var modal = parm.Adapt<SapDeliverRecord>().ToCreate(HttpContext);

            var response = _SapDeliverRecordService.AddSapDeliverRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 更新接口管理/SAP交验单记录表
        /// </summary>
        /// <returns></returns>
        [HttpPut]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:edit")]
        [Log(Title = "接口管理/SAP交验单记录表", BusinessType = BusinessType.UPDATE)]
        public IActionResult UpdateSapDeliverRecord([FromBody] SapDeliverRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求实体不能为空");
            }
            var modal = parm.Adapt<SapDeliverRecord>().ToUpdate(HttpContext);

            var response = _SapDeliverRecordService.UpdateSapDeliverRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 删除接口管理/SAP交验单记录表
        /// </summary>
        /// <returns></returns>
        [HttpDelete("{ids}")]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:delete")]
        [Log(Title = "接口管理/SAP交验单记录表", BusinessType = BusinessType.DELETE)]
        public IActionResult DeleteSapDeliverRecord(string ids)
        {
            int[] idsArr = Tools.SpitIntArrary(ids);
            if (idsArr.Length <= 0) { return ToResponse(ApiResult.Error($"删除失败Id 不能为空")); }

            var response = _SapDeliverRecordService.Delete(idsArr);

            return ToResponse(response);
        }



    }
}